@@ -18,7 +18,7 @@ setMethod(".ggraphicsnotebook",
             
             force(toolkit)
             
-            return(glabel("No ggraphics available in gWidgetstcltk", cont=container)@widget)
+            return(glabel("No ggraphics available in gWidgetstcltk", container=container)@widget)
             
           })
           
